@@ -86,7 +86,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         self._controller = controller
         self._io_mode = IOMode()
 
-    ''' Switch Input/Output prompt state '''
+    # Switch Input/Output prompt state
 
     def set_output(self):
         if self.is_disabled():
@@ -106,10 +106,10 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
                 self.__bufferring = False
             self._io_mode.set_input()
 
-    ''' Override Interface tff.EventObserver '''
+    # Override Interface tff.EventObserver
 
     def handle_esc(self, context, intermediate, final):
-        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+        if self._xterm_mouse_buffer is not None and self._io_mode.is_input():
             seq = self._xterm_mouse_buffer
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
@@ -130,7 +130,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         return False  # not handled
 
     def handle_csi(self, context, parameter, intermediate, final):
-        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+        if self._xterm_mouse_buffer is not None and self._io_mode.is_input():
             seq = self._xterm_mouse_buffer
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
@@ -166,7 +166,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         return False  # not handled
 
     def handle_ss2(self, context, final):
-        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+        if self._xterm_mouse_buffer is not None and self._io_mode.is_input():
             seq = self._xterm_mouse_buffer
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
@@ -186,7 +186,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         return False  # not handled
 
     def handle_ss3(self, context, final):
-        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+        if self._xterm_mouse_buffer is not None and self._io_mode.is_input():
             seq = self._xterm_mouse_buffer
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
@@ -206,7 +206,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         return False  # not handled
 
     def handle_control_string(self, context, prefix, value):
-        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+        if self._xterm_mouse_buffer is not None and self._io_mode.is_input():
             seq = self._xterm_mouse_buffer
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
@@ -227,7 +227,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         return False  # not handled
 
     def handle_char(self, context, c):
-        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+        if self._xterm_mouse_buffer is not None and self._io_mode.is_input():
             buf = self._xterm_mouse_buffer
             buf.append(c)
             self._xterm_mouse_counter -= 1
@@ -256,7 +256,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         return False  # not handled
 
     def handle_invalid(self, context, seq):
-        if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
+        if self._xterm_mouse_buffer is not None and self._io_mode.is_input():
             seq = self._xterm_mouse_buffer
             self._xterm_mouse_buffer = None
             self.handle_invalid(context, seq)
